#
# spec file for package rtl-sdr
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover	0
%define libname librtlsdr%{sover}
%define rtlsdr_group    rtlsdr
Name:           rtl-sdr
Version:        0.5.3+git.20170612
Release:        1.1
Summary:        Support programs for RTL2832
License:        GPL-2.0+
Group:          Productivity/Hamradio/Other
Url:            http://sdr.osmocom.org/trac/wiki/rtl-sdr
#Git-Clone:     https://git.osmocom.org/rtl-sdr
Source:         %{name}-%{version}.tar.xz
Patch0:         0001-Better-udev-handling.patch
BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
Programs that controls Realtek RTL2832 based DVB dongle in raw mode, so
it can be used as a SDR receiver.

%package -n %{libname}
Summary:        SDR driver for RTL2832
Group:          System/Libraries
Requires:       %{name}-udev

%description -n %{libname}
Library to run Realtek RTL2832 based DVB dongle as a SDR receiver.

%package udev
Summary:        Udev rules for RTL2832
Group:          Hardware/Other
Requires(pre):  shadow

%description udev
Udev rules for rtl-sdr driver

%package devel
Summary:        Development files for rtl-sdr
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
Library headers for rtl-sdr driver.

%prep
%setup -q
%patch0 -p1

%build
%cmake \
  -DINSTALL_UDEV_RULES=ON \
  -DUDEV_RULES_PATH=%{_udevrulesdir} \
  -DUDEV_RULES_GROUP=%{rtlsdr_group} \
  -DDETACH_KERNEL_DRIVER=ON
make %{?_smp_mflags}

%install
%cmake_install
rm %{buildroot}%{_libdir}/librtlsdr.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%pre udev
getent group %{rtlsdr_group} >/dev/null || groupadd -r %{rtlsdr_group}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README
%{_bindir}/rtl_adsb
%{_bindir}/rtl_eeprom
%{_bindir}/rtl_fm
%{_bindir}/rtl_power
%{_bindir}/rtl_sdr
%{_bindir}/rtl_tcp
%{_bindir}/rtl_test

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/librtlsdr.so.%{sover}*

%files udev
%defattr(-,root,root)
%{_udevrulesdir}/rtl-sdr.rules

%files devel
%defattr(-,root,root)
%{_libdir}/librtlsdr.so
%{_includedir}/rtl-sdr.h
%{_includedir}/rtl-sdr_export.h
%{_libdir}/pkgconfig/librtlsdr.pc

%changelog
* Thu Jun 15 2017 wk@ire.pw.edu.pl
- Update to version 0.5.3+git.20170612:
  * lib: use GPIO0 to control bias tee
  * rtl_(adsb|fm|power|tcp): add option -T for activating bias tee
* Sun Apr 23 2017 mardnh@gmx.de
- Use package-meta for tar_scm service and add git-core
  to BuildRequires
* Sun Apr 23 2017 mpluskal@suse.com
- Update group handling
* Sat Apr 15 2017 mardnh@gmx.de
- Add patch: 0001-Better-udev-handling.patch
- Use proper cmake options
- Use group rtlsdr in the udev-rules
* Thu Mar 23 2017 jengelh@inai.de
- RPM group fix
* Mon Mar  6 2017 mpluskal@suse.com
- Update to version 0.5.3+git.20161127:
  * lib: change default number of transfers to 15
  * rtl_tcp: make all global variables static
  * cmake: include resource file for MSVC builds
  * Correct return code of e4k_reg_write().
  * Allow setting bandwidth for R820T
  * New functions rtlsdr_set_tuner_bandwidth()
  * tools: allow built-in functions for newer versions of MSVC
  * lib: check for libusb init failure
  * lib: add new HanfTek dongle
- Packaging changes:
  * Add _service for easier updating of package
  * Split udev rules to separate package
  * Run spec-cleaner
* Sun Mar  5 2017 mpluskal@suse.com
- Use cmake macros
* Sun Dec  4 2016 dl8fcl@darc.de
- update to version 0.5.3_13_ge3e6ee2
  add new HanfTek dongle
* Wed Jun 10 2015 dl8fcl@darc.de
- update to version 0.5.3_12_ge3c03f7
  check for libusb init failure
* Sat May 16 2015 dl8fcl@darc.de
- update to version 0.5.3_10_g8b4d755
  Allow setting bandwidth for R820T
* Fri Sep  5 2014 dl8fcl@darc.de
- update to version 0.5.3_6_gd447a2e
* Fri Dec 20 2013 dl8fcl@darc.de
- update to version 0.5.2_2_g5f38c05
* Sun Nov  3 2013 lnt-sysadmin@lists.lrz.de
- Changes to spec file:
  * Update udev paths for openSUSE 13.1 and ensure udev rules are
    updated when package is installed / updated / uninstalled.
  * Define %%libname to ease reuse of %%post(un) macros
* Fri Nov  1 2013 dl8fcl@darc.de
- update to version 0.5.1
* Sun Sep 22 2013 dl8fcl@darc.de
- update to version 0.5.0_git20130915
* Tue Jul 23 2013 lnt-sysadmin@lists.lrz.de
- update to version 0.5.git
  * adds support for ASUS U3100MINI_PLUS_V2
  * set DETACH_KERNEL_DRIVER=ON to allow detaching of kernel driver
* Mon Jun 10 2013 dl8fcl@darc.de
- update to version git20130608
  minor enhancements
* Sun Apr 28 2013 dl8fcl@darc.de
- update to version git20130417.
  minor enhancements
* Thu Apr 11 2013 lnt-sysadmin@lists.lrz.de
- small changes to the spec file:
  * pass %%optflags to cmake according to
    http://en.opensuse.org/openSUSE:Build_system_recipes
  * use config(noreplace) for udev rules file
* Fri Mar 22 2013 dl8fcl@darc.de
- import into the hamradio repository
